GEODE-2316: Renamed namespace gemfire_statistics to apache::geode::statistics.


Project: http://git-wip-us.apache.org/repos/asf/geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/geode/commit/984d11c7
Tree: http://git-wip-us.apache.org/repos/asf/geode/tree/984d11c7
Diff: http://git-wip-us.apache.org/repos/asf/geode/diff/984d11c7

Branch: refs/heads/next-gen-native-client-software-grant
Commit: 984d11c70308b790372330f673a235275237995c
Parents: e4fd74f
Author: Jacob Barrett <jbarr...@pivotal.io>
Authored: Wed Jan 18 20:17:35 2017 -0800
Committer: Jacob Barrett <jbarr...@pivotal.io>
Committed: Mon Jan 23 11:15:37 2017 -0800

----------------------------------------------------------------------
 src/clicache/src/StatisticDescriptor.hpp        |  6 +++---
 src/clicache/src/Statistics.cpp                 | 20 ++++++++++----------
 src/clicache/src/Statistics.hpp                 |  6 +++---
 src/clicache/src/StatisticsFactory.cpp          | 20 ++++++++++----------
 src/clicache/src/StatisticsFactory.hpp          |  6 +++---
 src/clicache/src/StatisticsType.cpp             |  2 +-
 src/clicache/src/StatisticsType.hpp             |  6 +++---
 .../gfcpp/statistics/StatisticDescriptor.hpp    |  9 ++++++---
 .../include/gfcpp/statistics/Statistics.hpp     | 15 +++++++++++----
 .../gfcpp/statistics/StatisticsFactory.hpp      |  8 ++++++--
 .../include/gfcpp/statistics/StatisticsType.hpp |  8 ++++++--
 src/cppcache/src/AdminRegion.hpp                | 10 +++++++---
 src/cppcache/src/CachePerfStats.hpp             |  6 ++++--
 src/cppcache/src/CqQueryVsdStats.cpp            |  2 +-
 src/cppcache/src/CqQueryVsdStats.hpp            |  4 ++--
 src/cppcache/src/CqServiceVsdStats.cpp          |  2 +-
 src/cppcache/src/CqServiceVsdStats.hpp          |  4 ++--
 src/cppcache/src/DistributedSystem.cpp          |  2 +-
 src/cppcache/src/PoolStatistics.cpp             |  2 +-
 src/cppcache/src/PoolStatistics.hpp             | 16 +++++++++-------
 src/cppcache/src/RegionStats.cpp                |  2 +-
 src/cppcache/src/RegionStats.hpp                | 12 +++++++-----
 src/cppcache/src/StackTrace.cpp                 |  1 -
 src/cppcache/src/ThinClientPoolDM.cpp           |  2 +-
 src/cppcache/src/ThinClientPoolDM.hpp           | 12 ++++++++----
 src/cppcache/src/Utils.hpp                      |  5 ++---
 .../src/statistics/AtomicStatisticsImpl.cpp     |  2 +-
 .../src/statistics/AtomicStatisticsImpl.hpp     | 14 ++++++++++----
 .../src/statistics/GemfireStatisticsFactory.cpp |  2 +-
 .../src/statistics/GemfireStatisticsFactory.hpp |  8 ++++++--
 src/cppcache/src/statistics/HostStatHelper.cpp  |  2 +-
 src/cppcache/src/statistics/HostStatHelper.hpp  |  8 ++++++--
 .../src/statistics/HostStatHelperLinux.cpp      | 10 +++++++---
 .../src/statistics/HostStatHelperLinux.hpp      |  8 ++++++--
 .../src/statistics/HostStatHelperNull.hpp       |  8 ++++++--
 .../src/statistics/HostStatHelperSolaris.cpp    |  2 +-
 .../src/statistics/HostStatHelperSolaris.hpp    |  8 ++++++--
 .../src/statistics/HostStatHelperWin.cpp        |  2 +-
 .../src/statistics/HostStatHelperWin.hpp        |  8 ++++++--
 src/cppcache/src/statistics/HostStatSampler.cpp |  2 +-
 src/cppcache/src/statistics/HostStatSampler.hpp | 13 +++++++++----
 .../src/statistics/LinuxProcessStats.cpp        |  2 +-
 .../src/statistics/LinuxProcessStats.hpp        |  8 ++++++--
 .../src/statistics/NullProcessStats.cpp         |  2 +-
 .../src/statistics/NullProcessStats.hpp         | 12 +++++++-----
 .../src/statistics/OsStatisticsImpl.cpp         |  2 +-
 .../src/statistics/OsStatisticsImpl.hpp         | 13 +++++++++----
 .../src/statistics/PoolStatsSampler.cpp         |  2 +-
 .../src/statistics/PoolStatsSampler.hpp         |  8 ++++++--
 src/cppcache/src/statistics/ProcessStats.cpp    |  2 +-
 src/cppcache/src/statistics/ProcessStats.hpp    |  8 ++++++--
 .../src/statistics/SolarisProcessStats.cpp      |  2 +-
 .../src/statistics/SolarisProcessStats.hpp      |  8 ++++++--
 .../src/statistics/StatArchiveWriter.cpp        |  2 +-
 .../src/statistics/StatArchiveWriter.hpp        | 14 ++++++++++----
 .../src/statistics/StatSamplerStats.cpp         |  2 +-
 .../src/statistics/StatSamplerStats.hpp         |  8 ++++++--
 .../src/statistics/StatisticDescriptorImpl.cpp  |  2 +-
 .../src/statistics/StatisticDescriptorImpl.hpp  |  8 ++++++--
 src/cppcache/src/statistics/Statistics.cpp      |  2 +-
 .../src/statistics/StatisticsFactory.cpp        |  8 ++++++--
 .../src/statistics/StatisticsManager.cpp        |  4 ++--
 .../src/statistics/StatisticsManager.hpp        |  8 ++++++--
 .../src/statistics/StatisticsTypeImpl.cpp       |  2 +-
 .../src/statistics/StatisticsTypeImpl.hpp       |  8 ++++++--
 src/cppcache/src/statistics/StatsDef.hpp        |  8 ++++++--
 .../src/statistics/WindowsProcessStats.cpp      |  2 +-
 .../src/statistics/WindowsProcessStats.hpp      |  8 ++++++--
 68 files changed, 283 insertions(+), 157 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/StatisticDescriptor.hpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/StatisticDescriptor.hpp 
b/src/clicache/src/StatisticDescriptor.hpp
index f56dc2d..8d6f71b 100644
--- a/src/clicache/src/StatisticDescriptor.hpp
+++ b/src/clicache/src/StatisticDescriptor.hpp
@@ -42,7 +42,7 @@ namespace GemStone
       /// StatisticDescriptors are naturally ordered by their name.
       /// </para>
       public ref class StatisticDescriptor sealed
-        : public Internal::UMWrap<gemfire_statistics::StatisticDescriptor>
+        : public 
Internal::UMWrap<apache::geode::statistics::StatisticDescriptor>
        {
          public:
            /// <summary>
@@ -107,7 +107,7 @@ namespace GemStone
            /// the managed wrapper object, or null if the native pointer is 
null.
            /// </returns>
            inline static StatisticDescriptor^ Create(
-           gemfire_statistics::StatisticDescriptor* nativeptr )
+           apache::geode::statistics::StatisticDescriptor* nativeptr )
            {
              return ( nativeptr != nullptr ?
              gcnew StatisticDescriptor( nativeptr ) : nullptr );
@@ -118,7 +118,7 @@ namespace GemStone
            /// Private constructor to wrap a native object pointer
            /// </summary>
            /// <param name="nativeptr">The native object pointer</param>
-           inline StatisticDescriptor( 
gemfire_statistics::StatisticDescriptor* nativeptr )
+           inline StatisticDescriptor( 
apache::geode::statistics::StatisticDescriptor* nativeptr )
            : UMWrap( nativeptr, false ) { }
        };      
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/Statistics.cpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/Statistics.cpp b/src/clicache/src/Statistics.cpp
index de685be..5ef971c 100644
--- a/src/clicache/src/Statistics.cpp
+++ b/src/clicache/src/Statistics.cpp
@@ -106,7 +106,7 @@ namespace GemStone
       void Statistics::SetInt(StatisticDescriptor^ descriptor, int32_t value)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          
NativePtr->setInt(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),value);
+          
NativePtr->setInt(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),value);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */ 
       }
 
@@ -120,7 +120,7 @@ namespace GemStone
       void Statistics::SetLong(StatisticDescriptor^ descriptor, int64_t value)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          
NativePtr->setLong(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),value);
+          
NativePtr->setLong(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),value);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */ 
       }
 
@@ -150,7 +150,7 @@ namespace GemStone
       void Statistics::SetDouble(StatisticDescriptor^ descriptor, double value)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-            
NativePtr->setDouble(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),
 value);
+            
NativePtr->setDouble(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),
 value);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -164,7 +164,7 @@ namespace GemStone
       int32_t Statistics::GetInt(StatisticDescriptor^ descriptor)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          return 
NativePtr->getInt(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor));
+          return 
NativePtr->getInt(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor));
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -185,7 +185,7 @@ namespace GemStone
        int64_t Statistics::GetLong(StatisticDescriptor^ descriptor)
        {
           _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-            return 
NativePtr->getLong(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor));
+            return 
NativePtr->getLong(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor));
           _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
        }
 
@@ -207,7 +207,7 @@ namespace GemStone
       double Statistics::GetDouble(StatisticDescriptor^ descriptor)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-           return 
NativePtr->getDouble(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor));
+           return 
NativePtr->getDouble(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor));
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -222,7 +222,7 @@ namespace GemStone
       int64_t Statistics::GetRawBits(StatisticDescriptor^ descriptor)
       {
          _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-           return 
NativePtr->getRawBits(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor));
+           return 
NativePtr->getRawBits(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor));
          _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -236,7 +236,7 @@ namespace GemStone
       int32_t Statistics::IncInt(StatisticDescriptor^ descriptor, int32_t 
delta)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          return 
NativePtr->incInt(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),delta);
+          return 
NativePtr->incInt(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),delta);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -258,7 +258,7 @@ namespace GemStone
       int64_t Statistics::IncLong(StatisticDescriptor^ descriptor, int64_t 
delta)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          return 
NativePtr->incLong(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),delta);
+          return 
NativePtr->incLong(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),delta);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 
@@ -280,7 +280,7 @@ namespace GemStone
       double Statistics::IncDouble(StatisticDescriptor^ descriptor, double 
delta)
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
-          return 
NativePtr->incDouble(GetNativePtr<gemfire_statistics::StatisticDescriptor>(descriptor),delta);
+          return 
NativePtr->incDouble(GetNativePtr<apache::geode::statistics::StatisticDescriptor>(descriptor),delta);
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/Statistics.hpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/Statistics.hpp b/src/clicache/src/Statistics.hpp
index a1b4944..d7d4a6e 100644
--- a/src/clicache/src/Statistics.hpp
+++ b/src/clicache/src/Statistics.hpp
@@ -44,7 +44,7 @@ namespace GemStone
       /// method.
       /// </para>
       public ref class Statistics sealed
-        : public Internal::UMWrapN<gemfire_statistics::Statistics>
+        : public Internal::UMWrapN<apache::geode::statistics::Statistics>
        {
        public:
 
@@ -517,7 +517,7 @@ namespace GemStone
            /// the managed wrapper object, or null if the native pointer is 
null.
            /// </returns>
           inline static Statistics^ Create(
-          gemfire_statistics::Statistics* nativeptr )
+          apache::geode::statistics::Statistics* nativeptr )
           {
             return ( nativeptr != nullptr ?
             gcnew Statistics( nativeptr ) : nullptr );
@@ -528,7 +528,7 @@ namespace GemStone
            /// Private constructor to wrap a native object pointer
            /// </summary>
            /// <param name="nativeptr">The native object pointer</param>
-          inline Statistics( gemfire_statistics::Statistics* nativeptr )
+          inline Statistics( apache::geode::statistics::Statistics* nativeptr )
           : UMWrapN( nativeptr, false ) { }
 
       };

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/StatisticsFactory.cpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/StatisticsFactory.cpp 
b/src/clicache/src/StatisticsFactory.cpp
index ad58d70..1689a8b 100644
--- a/src/clicache/src/StatisticsFactory.cpp
+++ b/src/clicache/src/StatisticsFactory.cpp
@@ -38,7 +38,7 @@ namespace GemStone
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          return 
StatisticsFactory::Create(gemfire_statistics::StatisticsFactory::getExistingInstance());
+          return 
StatisticsFactory::Create(apache::geode::statistics::StatisticsFactory::getExistingInstance());
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -153,10 +153,10 @@ namespace GemStone
         ManagedString mg_description( description );
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
                 
-          gemfire_statistics::StatisticDescriptor ** nativedescriptors = new 
gemfire_statistics::StatisticDescriptor*[statsLength];
+          apache::geode::statistics::StatisticDescriptor ** nativedescriptors 
= new apache::geode::statistics::StatisticDescriptor*[statsLength];
           for (int32_t index = 0; index < statsLength; index++)
           {
-            nativedescriptors[index] = 
GetNativePtr<gemfire_statistics::StatisticDescriptor>(stats[index]);
+            nativedescriptors[index] = 
GetNativePtr<apache::geode::statistics::StatisticDescriptor>(stats[index]);
           }
           return StatisticsType::Create(NativePtr->createType(mg_name.CharPtr, 
mg_description.CharPtr, nativedescriptors, statsLength));
           
@@ -177,7 +177,7 @@ namespace GemStone
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
          
-          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type)));
+          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type)));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -187,7 +187,7 @@ namespace GemStone
         ManagedString mg_text( textId );
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type),(char*)mg_text.CharPtr));
+          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type),(char*)mg_text.CharPtr));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -197,7 +197,7 @@ namespace GemStone
         ManagedString mg_text( textId );
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type),(char*)mg_text.CharPtr,
 numericId));
+          return 
Statistics::Create(NativePtr->createStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type),(char*)mg_text.CharPtr,
 numericId));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -206,7 +206,7 @@ namespace GemStone
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
          
-          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type)));
+          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type)));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -216,7 +216,7 @@ namespace GemStone
         ManagedString mg_text( textId );
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type),(char*)mg_text.CharPtr));
+          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type),(char*)mg_text.CharPtr));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -226,7 +226,7 @@ namespace GemStone
         ManagedString mg_text( textId );
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<gemfire_statistics::StatisticsType>(type),(char*)mg_text.CharPtr,
 numericId));
+          return 
Statistics::Create(NativePtr->createAtomicStatistics(GetNativePtr<apache::geode::statistics::StatisticsType>(type),(char*)mg_text.CharPtr,
 numericId));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }
@@ -234,7 +234,7 @@ namespace GemStone
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
          
-          return 
Statistics::Create(NativePtr->findFirstStatisticsByType(GetNativePtr<gemfire_statistics::StatisticsType>(type)));
+          return 
Statistics::Create(NativePtr->findFirstStatisticsByType(GetNativePtr<apache::geode::statistics::StatisticsType>(type)));
 
         _GF_MG_EXCEPTION_CATCH_ALL2/* due to auto replace */
       }

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/StatisticsFactory.hpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/StatisticsFactory.hpp 
b/src/clicache/src/StatisticsFactory.hpp
index 877e588..d49aaba 100644
--- a/src/clicache/src/StatisticsFactory.hpp
+++ b/src/clicache/src/StatisticsFactory.hpp
@@ -53,7 +53,7 @@ namespace GemStone
       /// is, exceeds its maximum value).
       /// </para>
       public ref class StatisticsFactory sealed
-        : public Internal::UMWrap<gemfire_statistics::StatisticsFactory>
+        : public Internal::UMWrap<apache::geode::statistics::StatisticsFactory>
       {
         protected:
           StatisticsFactory(){}
@@ -245,7 +245,7 @@ namespace GemStone
            /// the managed wrapper object, or null if the native pointer is 
null.
            /// </returns>
            inline static StatisticsFactory^ Create(
-           gemfire_statistics::StatisticsFactory* nativeptr )
+           apache::geode::statistics::StatisticsFactory* nativeptr )
            {
              return ( nativeptr != nullptr ?
              gcnew StatisticsFactory( nativeptr ) : nullptr );
@@ -256,7 +256,7 @@ namespace GemStone
            /// Private constructor to wrap a native object pointer
            /// </summary>
            /// <param name="nativeptr">The native object pointer</param>
-           inline StatisticsFactory( gemfire_statistics::StatisticsFactory* 
nativeptr )
+           inline StatisticsFactory( 
apache::geode::statistics::StatisticsFactory* nativeptr )
            : UMWrap( nativeptr, false ) { }
       };
     }

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/StatisticsType.cpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/StatisticsType.cpp 
b/src/clicache/src/StatisticsType.cpp
index f566875..880cdf4 100644
--- a/src/clicache/src/StatisticsType.cpp
+++ b/src/clicache/src/StatisticsType.cpp
@@ -46,7 +46,7 @@ namespace GemStone
       {
         _GF_MG_EXCEPTION_TRY2/* due to auto replace */
 
-          gemfire_statistics::StatisticDescriptor ** nativedescriptors = 
NativePtr->getStatistics();
+          apache::geode::statistics::StatisticDescriptor ** nativedescriptors 
= NativePtr->getStatistics();
           array<StatisticDescriptor^>^ descriptors = gcnew 
array<StatisticDescriptor^>(NativePtr->getDescriptorsCount());
           for (int item = 0; item < NativePtr->getDescriptorsCount(); item++)
           {

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/clicache/src/StatisticsType.hpp
----------------------------------------------------------------------
diff --git a/src/clicache/src/StatisticsType.hpp 
b/src/clicache/src/StatisticsType.hpp
index d932a01..d18b315 100644
--- a/src/clicache/src/StatisticsType.hpp
+++ b/src/clicache/src/StatisticsType.hpp
@@ -46,7 +46,7 @@ namespace GemStone
       /// method.
       /// </para>
       public ref class StatisticsType sealed
-        : public Internal::UMWrap<gemfire_statistics::StatisticsType>
+        : public Internal::UMWrap<apache::geode::statistics::StatisticsType>
       {
       public:
         /// <summary>
@@ -116,7 +116,7 @@ namespace GemStone
         /// the managed wrapper object, or null if the native pointer is null.
         /// </returns>
         inline static StatisticsType^ Create(
-          gemfire_statistics::StatisticsType* nativeptr )
+          apache::geode::statistics::StatisticsType* nativeptr )
         {
           return ( nativeptr != nullptr ?
             gcnew StatisticsType( nativeptr ) : nullptr );
@@ -127,7 +127,7 @@ namespace GemStone
         /// Private constructor to wrap a native object pointer
         /// </summary>
         /// <param name="nativeptr">The native object pointer</param>
-        inline StatisticsType( gemfire_statistics::StatisticsType* nativeptr )
+        inline StatisticsType( apache::geode::statistics::StatisticsType* 
nativeptr )
           : UMWrap( nativeptr, false ) { }
 
       };

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/include/gfcpp/statistics/StatisticDescriptor.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/include/gfcpp/statistics/StatisticDescriptor.hpp 
b/src/cppcache/include/gfcpp/statistics/StatisticDescriptor.hpp
index 3e1dab8..2aa45a5 100644
--- a/src/cppcache/include/gfcpp/statistics/StatisticDescriptor.hpp
+++ b/src/cppcache/include/gfcpp/statistics/StatisticDescriptor.hpp
@@ -25,7 +25,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Describes an individual statistic whose value is updated by an
@@ -82,7 +84,8 @@ class CPPCACHE_EXPORT StatisticDescriptor {
   virtual ~StatisticDescriptor() {}
 
 };  // class
-
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_STATISTICS_STATISTICDESCRIPTOR_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/include/gfcpp/statistics/Statistics.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/include/gfcpp/statistics/Statistics.hpp 
b/src/cppcache/include/gfcpp/statistics/Statistics.hpp
index 15c155c..bba0782 100644
--- a/src/cppcache/include/gfcpp/statistics/Statistics.hpp
+++ b/src/cppcache/include/gfcpp/statistics/Statistics.hpp
@@ -24,7 +24,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * An instantiation of an existing <code>StatisticsType</code> object with
  * methods for
@@ -212,7 +214,9 @@ class CPPCACHE_EXPORT Statistics {
    *         if the described statistic is not of
    *         type <code>double</code>.
    */
-  virtual void setDouble(StatisticDescriptor* descriptor, double value) = 0;
+  virtual void setDouble(
+      apache::geode::statistics::StatisticDescriptor* descriptor,
+      double value) = 0;
   /**
    * Sets the value of a named statistic of type <code>double</code>.
    *
@@ -249,7 +253,8 @@ class CPPCACHE_EXPORT Statistics {
    *         if the described statistic is not of
    *         type <code>int</code>.
    */
-  virtual int32 getInt(StatisticDescriptor* descriptor) = 0;
+  virtual int32 getInt(
+      apache::geode::statistics::StatisticDescriptor* descriptor) = 0;
   /**
    * Returns the value of the statistic of type <code>int</code> at
    * the given name.
@@ -517,6 +522,8 @@ class CPPCACHE_EXPORT Statistics {
   virtual ~Statistics() = 0;
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_STATISTICS_STATISTICS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/include/gfcpp/statistics/StatisticsFactory.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/include/gfcpp/statistics/StatisticsFactory.hpp 
b/src/cppcache/include/gfcpp/statistics/StatisticsFactory.hpp
index 7c31624..b03fc11 100644
--- a/src/cppcache/include/gfcpp/statistics/StatisticsFactory.hpp
+++ b/src/cppcache/include/gfcpp/statistics/StatisticsFactory.hpp
@@ -25,7 +25,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Instances of this interface provide methods that create instances
@@ -211,6 +213,8 @@ class CPPCACHE_EXPORT StatisticsFactory {
   const StatisticsFactory& operator=(const StatisticsFactory&);
 
 };  // class
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  //  _GEMFIRE__STATISTICS_STATISTICSFACTORY_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/include/gfcpp/statistics/StatisticsType.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/include/gfcpp/statistics/StatisticsType.hpp 
b/src/cppcache/include/gfcpp/statistics/StatisticsType.hpp
index ee32210..1991097 100644
--- a/src/cppcache/include/gfcpp/statistics/StatisticsType.hpp
+++ b/src/cppcache/include/gfcpp/statistics/StatisticsType.hpp
@@ -24,7 +24,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Used to describe a logical collection of StatisticDescriptors. These
@@ -87,6 +89,8 @@ class CPPCACHE_EXPORT StatisticsType {
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef __GEMFIRE_STATISTICSTYPE_H__

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/AdminRegion.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/AdminRegion.hpp b/src/cppcache/src/AdminRegion.hpp
index 489c236..c2dcd70 100644
--- a/src/cppcache/src/AdminRegion.hpp
+++ b/src/cppcache/src/AdminRegion.hpp
@@ -25,9 +25,13 @@
 //#include <statistics/HostStatSampler.hpp>
 
 #include "NonCopyable.hpp"
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 class HostStatSampler;
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 namespace apache {
 namespace geode {
@@ -68,7 +72,7 @@ class AdminRegion : public SharedBase,
   void put(const CacheableKeyPtr& keyPtr, const CacheablePtr& valuePtr);
   AdminRegion(CacheImpl* cache, ThinClientBaseDM* distMan = NULL);
   ~AdminRegion();
-  friend class gemfire_statistics::HostStatSampler;
+  friend class apache::geode::statistics::HostStatSampler;
 };
 
 typedef SharedPtr<AdminRegion> AdminRegionPtr;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/CachePerfStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CachePerfStats.hpp 
b/src/cppcache/src/CachePerfStats.hpp
index d64400c..df3bed1 100644
--- a/src/cppcache/src/CachePerfStats.hpp
+++ b/src/cppcache/src/CachePerfStats.hpp
@@ -26,7 +26,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /** hold statistics for cache.. */
 class CPPCACHE_EXPORT CachePerfStats {
@@ -278,7 +278,9 @@ class CPPCACHE_EXPORT CachePerfStats {
     m_cachePerfStats->incInt(m_pdxInstanceDeserializationsId, 1);
   }
 
-  inline gemfire_statistics::Statistics* getStat() { return m_cachePerfStats; }
+  inline apache::geode::statistics::Statistics* getStat() {
+    return m_cachePerfStats;
+  }
 
   inline int32_t getPdxInstanceDeserializationTimeId() {
     return m_pdxInstanceDeserializationTimeId;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/CqQueryVsdStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryVsdStats.cpp 
b/src/cppcache/src/CqQueryVsdStats.cpp
index 7ca1590..133e7a6 100644
--- a/src/cppcache/src/CqQueryVsdStats.cpp
+++ b/src/cppcache/src/CqQueryVsdStats.cpp
@@ -32,7 +32,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 
////////////////////////////////////////////////////////////////////////////////
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/CqQueryVsdStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqQueryVsdStats.hpp 
b/src/cppcache/src/CqQueryVsdStats.hpp
index 4a72a83..979f771 100644
--- a/src/cppcache/src/CqQueryVsdStats.hpp
+++ b/src/cppcache/src/CqQueryVsdStats.hpp
@@ -28,7 +28,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 class CPPCACHE_EXPORT CqQueryVsdStats : public CqStatistics {
  public:
@@ -62,7 +62,7 @@ class CPPCACHE_EXPORT CqQueryVsdStats : public CqStatistics {
   }
 
  private:
-  gemfire_statistics::Statistics* m_cqQueryVsdStats;
+  apache::geode::statistics::Statistics* m_cqQueryVsdStats;
 
   int32_t m_numInsertsId;
   int32_t m_numUpdatesId;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/CqServiceVsdStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqServiceVsdStats.cpp 
b/src/cppcache/src/CqServiceVsdStats.cpp
index 5155fb5..c20588f 100644
--- a/src/cppcache/src/CqServiceVsdStats.cpp
+++ b/src/cppcache/src/CqServiceVsdStats.cpp
@@ -32,7 +32,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 
////////////////////////////////////////////////////////////////////////////////
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/CqServiceVsdStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/CqServiceVsdStats.hpp 
b/src/cppcache/src/CqServiceVsdStats.hpp
index 170f5b1..1e53f2f 100644
--- a/src/cppcache/src/CqServiceVsdStats.hpp
+++ b/src/cppcache/src/CqServiceVsdStats.hpp
@@ -28,7 +28,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 class CPPCACHE_EXPORT CqServiceVsdStats : public CqServiceStatistics {
  public:
@@ -95,7 +95,7 @@ class CPPCACHE_EXPORT CqServiceVsdStats : public 
CqServiceStatistics {
   }
 
  private:
-  gemfire_statistics::Statistics* m_cqServiceVsdStats;
+  apache::geode::statistics::Statistics* m_cqServiceVsdStats;
 
   int32_t m_numCqsActiveId;
   int32_t m_numCqsCreatedId;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/DistributedSystem.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/DistributedSystem.cpp 
b/src/cppcache/src/DistributedSystem.cpp
index 3edb9ab..ef535b7 100644
--- a/src/cppcache/src/DistributedSystem.cpp
+++ b/src/cppcache/src/DistributedSystem.cpp
@@ -42,7 +42,7 @@
 #include "version.h"
 
 using namespace apache::geode::client;
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 DistributedSystemPtr* DistributedSystem::m_instance_ptr = NULL;
 bool DistributedSystem::m_connected = false;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/PoolStatistics.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/PoolStatistics.cpp 
b/src/cppcache/src/PoolStatistics.cpp
index b007f83..158717e 100644
--- a/src/cppcache/src/PoolStatistics.cpp
+++ b/src/cppcache/src/PoolStatistics.cpp
@@ -29,7 +29,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 
////////////////////////////////////////////////////////////////////////////////
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/PoolStatistics.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/PoolStatistics.hpp 
b/src/cppcache/src/PoolStatistics.hpp
index c4a2442..3e94253 100644
--- a/src/cppcache/src/PoolStatistics.hpp
+++ b/src/cppcache/src/PoolStatistics.hpp
@@ -28,7 +28,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 class PoolStats {
  public:
@@ -40,7 +40,7 @@ class PoolStats {
 
   void close() {
     getStats()->close();
-    StatisticsManager::getExistingInstance()->forceSample();
+    statistics::StatisticsManager::getExistingInstance()->forceSample();
   }
 
   void setLocators(int32 curVal) { getStats()->setInt(m_locatorsId, curVal); }
@@ -123,11 +123,13 @@ class PoolStats {
   void incQueryExecutionTimeId(int64 value) {  // counter
     getStats()->incLong(m_queryExecutionTimeId, value);
   }
-  inline gemfire_statistics::Statistics* getStats() { return m_poolStats; }
+  inline apache::geode::statistics::Statistics* getStats() {
+    return m_poolStats;
+  }
 
  private:
-  // volatile gemfire_statistics::Statistics* m_poolStats;
-  gemfire_statistics::Statistics* m_poolStats;
+  // volatile apache::geode::statistics::Statistics* m_poolStats;
+  apache::geode::statistics::Statistics* m_poolStats;
 
   int32_t m_locatorsId;
   int32_t m_serversId;
@@ -167,13 +169,13 @@ class PoolStatType {
  public:
   static PoolStatType* getInstance();
 
-  StatisticsType* getStatType();
+  statistics::StatisticsType* getStatType();
 
   static void clean();
 
  private:
   PoolStatType();
-  StatisticDescriptor* m_stats[27];
+  statistics::StatisticDescriptor* m_stats[27];
 
   int32_t m_locatorsId;
   int32_t m_serversId;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/RegionStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/RegionStats.cpp b/src/cppcache/src/RegionStats.cpp
index a96deb2..595809b 100644
--- a/src/cppcache/src/RegionStats.cpp
+++ b/src/cppcache/src/RegionStats.cpp
@@ -32,7 +32,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 
////////////////////////////////////////////////////////////////////////////////
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/RegionStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/RegionStats.hpp b/src/cppcache/src/RegionStats.hpp
index 67e261f..2677751 100644
--- a/src/cppcache/src/RegionStats.hpp
+++ b/src/cppcache/src/RegionStats.hpp
@@ -30,7 +30,7 @@ namespace apache {
 namespace geode {
 namespace client {
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 class CPPCACHE_EXPORT RegionStats {
  public:
@@ -90,10 +90,12 @@ class CPPCACHE_EXPORT RegionStats {
 
   inline void incClears() { m_regionStats->incInt(m_clearsId, 1); }
 
-  inline gemfire_statistics::Statistics* getStat() { return m_regionStats; }
+  inline apache::geode::statistics::Statistics* getStat() {
+    return m_regionStats;
+  }
 
  private:
-  gemfire_statistics::Statistics* m_regionStats;
+  apache::geode::statistics::Statistics* m_regionStats;
 
   int32_t m_destroysId;
   int32_t m_createsId;
@@ -133,13 +135,13 @@ class RegionStatType {
  public:
   static RegionStatType* getInstance();
 
-  StatisticsType* getStatType();
+  statistics::StatisticsType* getStatType();
 
   static void clean();
 
  private:
   RegionStatType();
-  StatisticDescriptor* m_stats[26];
+  statistics::StatisticDescriptor* m_stats[26];
 
   int32_t m_destroysId;
   int32_t m_createsId;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/StackTrace.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/StackTrace.cpp b/src/cppcache/src/StackTrace.cpp
index f3dab7d..527b4d9 100644
--- a/src/cppcache/src/StackTrace.cpp
+++ b/src/cppcache/src/StackTrace.cpp
@@ -91,7 +91,6 @@ void StackTrace::addFrame(std::list<std::string>& frames) {
 }  // namespace geode
 }  // namespace apache
 
-
 #elif defined(_LINUX)
 #include <execinfo.h>
 #include <signal.h>

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/ThinClientPoolDM.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ThinClientPoolDM.cpp 
b/src/cppcache/src/ThinClientPoolDM.cpp
index 514085d..df6d8ed 100644
--- a/src/cppcache/src/ThinClientPoolDM.cpp
+++ b/src/cppcache/src/ThinClientPoolDM.cpp
@@ -33,7 +33,7 @@
 #include "NonCopyable.hpp"
 
 using namespace apache::geode::client;
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 ExpiryTaskManager* getCacheImplExpiryTaskManager();
 void removePool(const char*);

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/ThinClientPoolDM.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/ThinClientPoolDM.hpp 
b/src/cppcache/src/ThinClientPoolDM.hpp
index 03e34a7..84c3481 100644
--- a/src/cppcache/src/ThinClientPoolDM.hpp
+++ b/src/cppcache/src/ThinClientPoolDM.hpp
@@ -40,10 +40,14 @@
 
 #include "NonCopyable.hpp"
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 class PoolStatsSampler;
-}  // namespace gemfire_statistics
-using namespace gemfire_statistics;
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
+using namespace apache::geode::statistics;
 namespace apache {
 namespace geode {
 namespace client {
@@ -413,7 +417,7 @@ class ThinClientPoolDM
   void cleanStaleConnections(volatile bool& isRunning);
   void restoreMinConnections(volatile bool& isRunning);
   volatile int32 m_clientOps;  // Actual Size of Pool
-  PoolStatsSampler* m_PoolStatsSampler;
+  statistics::PoolStatsSampler* m_PoolStatsSampler;
   ClientMetadataService* m_clientMetadataService;
   friend class CacheImpl;
   friend class ThinClientStickyManager;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/Utils.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/Utils.hpp b/src/cppcache/src/Utils.hpp
index ab382de..1202566 100644
--- a/src/cppcache/src/Utils.hpp
+++ b/src/cppcache/src/Utils.hpp
@@ -179,9 +179,8 @@ class CPPCACHE_EXPORT Utils {
     return objectSize;
   }
 
-  inline static void updateStatOpTime(
-      gemfire_statistics::Statistics* m_regionStats, int32 statId,
-      int64 start) {
+  inline static void updateStatOpTime(statistics::Statistics* m_regionStats,
+                                      int32 statId, int64 start) {
     if (DistributedSystem::getSystemProperties() != NULL) {
       if (DistributedSystem::getSystemProperties()->getEnableTimeStatistics()) 
{
         m_regionStats->incLong(statId, startStatOpTime() - start);

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/AtomicStatisticsImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/AtomicStatisticsImpl.cpp 
b/src/cppcache/src/statistics/AtomicStatisticsImpl.cpp
index dd2da3e..c43f274 100644
--- a/src/cppcache/src/statistics/AtomicStatisticsImpl.cpp
+++ b/src/cppcache/src/statistics/AtomicStatisticsImpl.cpp
@@ -24,7 +24,7 @@
 #include "StatisticsTypeImpl.hpp"
 #include "StatisticDescriptorImpl.hpp"
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 /**
  * An implementation of {@link Statistics} that stores its statistics
  * in local  memory and supports atomic operations.

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp 
b/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
index 83e32e5..9a7d815 100644
--- a/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
+++ b/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
@@ -31,7 +31,7 @@
 #include "HostStatHelper.hpp"
 
 using namespace apache::geode::client;
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * static member initialization

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp 
b/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
index ac1ef0f..1d59e3f 100644
--- a/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
+++ b/src/cppcache/src/statistics/GemfireStatisticsFactory.hpp
@@ -37,7 +37,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 class StatisticsManager;
 
@@ -144,6 +146,8 @@ class GemfireStatisticsFactory : public StatisticsFactory {
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //  _GEMFIRE_STATISTICS_GEMFIRESTATISTICSFACTORY_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelper.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelper.cpp 
b/src/cppcache/src/statistics/HostStatHelper.cpp
index 16d740a..84a816c 100644
--- a/src/cppcache/src/statistics/HostStatHelper.cpp
+++ b/src/cppcache/src/statistics/HostStatHelper.cpp
@@ -21,7 +21,7 @@
 #include "HostStatHelper.hpp"
 #include "GemfireStatisticsFactory.hpp"
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * Provides native methods which fetch operating system statistics.

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelper.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelper.hpp 
b/src/cppcache/src/statistics/HostStatHelper.hpp
index 93a280c..648e5fe 100644
--- a/src/cppcache/src/statistics/HostStatHelper.hpp
+++ b/src/cppcache/src/statistics/HostStatHelper.hpp
@@ -40,7 +40,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * Provides native methods which fetch operating system statistics.
  * accessed by calling {@link #getInstance()}.
@@ -72,5 +74,7 @@ class CPPCACHE_EXPORT HostStatHelper {
 
   static void cleanup();
 };
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  //_GEMFIRE_STATISTICS_HOSTSTATHELPER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperLinux.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperLinux.cpp 
b/src/cppcache/src/statistics/HostStatHelperLinux.cpp
index f24af95..e08f7f7 100644
--- a/src/cppcache/src/statistics/HostStatHelperLinux.cpp
+++ b/src/cppcache/src/statistics/HostStatHelperLinux.cpp
@@ -25,12 +25,16 @@
 #include "LinuxProcessStats.hpp"
 #include <ace/OS.h>
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 double lastIdle = 0;
 double lastUptime = 0;
-}
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 uint8_t HostStatHelperLinux::m_logStatErrorCountDown = 5;
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperLinux.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperLinux.hpp 
b/src/cppcache/src/statistics/HostStatHelperLinux.hpp
index ca7c063..ffa5d7e 100644
--- a/src/cppcache/src/statistics/HostStatHelperLinux.hpp
+++ b/src/cppcache/src/statistics/HostStatHelperLinux.hpp
@@ -26,7 +26,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Linux Implementation to fetch operating system stats.
@@ -41,7 +43,9 @@ class HostStatHelperLinux {
  private:
   static uint8_t m_logStatErrorCountDown;
 };
-};
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // if def(_LINUX)
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperNull.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperNull.hpp 
b/src/cppcache/src/statistics/HostStatHelperNull.hpp
index e51fdff..8268552 100644
--- a/src/cppcache/src/statistics/HostStatHelperNull.hpp
+++ b/src/cppcache/src/statistics/HostStatHelperNull.hpp
@@ -22,12 +22,16 @@
 /** @file
  */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 class HostStatHelperNull {
  public:
   static void refreshProcess(ProcessStats* processStats) {}
 };
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_STATISTICS_HOSTSTATHELPERLINUX_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperSolaris.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperSolaris.cpp 
b/src/cppcache/src/statistics/HostStatHelperSolaris.cpp
index e35ed3b..7b0ee5c 100644
--- a/src/cppcache/src/statistics/HostStatHelperSolaris.cpp
+++ b/src/cppcache/src/statistics/HostStatHelperSolaris.cpp
@@ -34,7 +34,7 @@
 #include "SolarisProcessStats.hpp"
 #include <ace/OS.h>
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 uint8_t HostStatHelperSolaris::m_logStatErrorCountDown = 5;
 uint32_t HostStatHelperSolaris::m_cpuUtilPrev[CPU_STATES] = {0};

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperSolaris.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperSolaris.hpp 
b/src/cppcache/src/statistics/HostStatHelperSolaris.hpp
index 8a266b7..9b553e4 100644
--- a/src/cppcache/src/statistics/HostStatHelperSolaris.hpp
+++ b/src/cppcache/src/statistics/HostStatHelperSolaris.hpp
@@ -37,7 +37,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Solaris Implementation to fetch operating system stats.
@@ -57,7 +59,9 @@ class HostStatHelperSolaris {
   static bool m_initialized;
   static void getKernelStats(uint32_t*);
 };
-};
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // if def(_SOLARIS)
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperWin.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperWin.cpp 
b/src/cppcache/src/statistics/HostStatHelperWin.cpp
index 33256ea..f5c4926 100644
--- a/src/cppcache/src/statistics/HostStatHelperWin.cpp
+++ b/src/cppcache/src/statistics/HostStatHelperWin.cpp
@@ -29,7 +29,7 @@
  */
 
 #if defined(_WIN32)
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 PPERF_DATA_BLOCK HostStatHelperWin::PerfData = NULL;
 PPERF_OBJECT_TYPE HostStatHelperWin::ProcessObj = NULL;

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatHelperWin.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatHelperWin.hpp 
b/src/cppcache/src/statistics/HostStatHelperWin.hpp
index 1666a46..d941ac5 100644
--- a/src/cppcache/src/statistics/HostStatHelperWin.hpp
+++ b/src/cppcache/src/statistics/HostStatHelperWin.hpp
@@ -33,7 +33,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Windows2000 Implementation of code to fetch operating system stats.
@@ -292,7 +294,9 @@ class HostStatHelperWin {
 
 };  // class
 
-};  // namespace
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // (_WIN32)
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatSampler.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/HostStatSampler.cpp 
b/src/cppcache/src/statistics/HostStatSampler.cpp
index e1e56b8..b2d1896 100644
--- a/src/cppcache/src/statistics/HostStatSampler.cpp
+++ b/src/cppcache/src/statistics/HostStatSampler.cpp
@@ -38,7 +38,7 @@
 #include "GemfireStatisticsFactory.hpp"
 #include <ClientHealthStats.hpp>
 #include <ClientProxyMembershipID.hpp>
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 using namespace apache::geode::client;
 
 namespace gemfire_stats_globals {

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/HostStatSampler.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/LinuxProcessStats.cpp 
b/src/cppcache/src/statistics/LinuxProcessStats.cpp
index 1918781..6a87c42 100644
--- a/src/cppcache/src/statistics/LinuxProcessStats.cpp
+++ b/src/cppcache/src/statistics/LinuxProcessStats.cpp
@@ -20,7 +20,7 @@
 #include "LinuxProcessStats.hpp"
 #include "GemfireStatisticsFactory.hpp"
 #include "HostStatHelperLinux.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * <P>This class provides the interface for statistics about a

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/LinuxProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/LinuxProcessStats.hpp 
b/src/cppcache/src/statistics/LinuxProcessStats.hpp
index 8596b15..fb91e41 100644
--- a/src/cppcache/src/statistics/LinuxProcessStats.hpp
+++ b/src/cppcache/src/statistics/LinuxProcessStats.hpp
@@ -28,7 +28,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * <P>This class provides the interface for statistics about a
  * Linux operating system process that is using a GemFire system.
@@ -73,6 +75,8 @@ class CPPCACHE_EXPORT LinuxProcessStats : public ProcessStats 
{
 
 };  // Class LinuxProcessStats
 
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //_GEMFIRE_STATISTICS_LINUXPROCESSSTATS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/NullProcessStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/NullProcessStats.cpp 
b/src/cppcache/src/statistics/NullProcessStats.cpp
index fb6fbac..65ffca4 100644
--- a/src/cppcache/src/statistics/NullProcessStats.cpp
+++ b/src/cppcache/src/statistics/NullProcessStats.cpp
@@ -20,7 +20,7 @@
 #include "NullProcessStats.hpp"
 #include "GemfireStatisticsFactory.hpp"
 #include "HostStatHelperNull.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * <P>This class provides the interface for statistics about a

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/NullProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/NullProcessStats.hpp 
b/src/cppcache/src/statistics/NullProcessStats.hpp
index 95f5f57..1b8662b 100644
--- a/src/cppcache/src/statistics/NullProcessStats.hpp
+++ b/src/cppcache/src/statistics/NullProcessStats.hpp
@@ -28,7 +28,9 @@ using namespace apache::geode::client;
 /** @file
  */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * <P>This class provides the interface for statistics about a
  * Null operating system process that is using a GemFire system.
@@ -46,9 +48,9 @@ class CPPCACHE_EXPORT NullProcessStats : public ProcessStats {
   int32 getNumThreads();
   int64 getAllCpuTime();
   void close();
-};
-// Class NullProcessStats
-}  // namespace gemfire_statistics
-// NameSpace
+};  // Class NullProcessStats
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //_GEMFIRE_STATISTICS_NULLPROCESSSTATS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/OsStatisticsImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/OsStatisticsImpl.cpp 
b/src/cppcache/src/statistics/OsStatisticsImpl.cpp
index 795720d..668ddf3 100644
--- a/src/cppcache/src/statistics/OsStatisticsImpl.cpp
+++ b/src/cppcache/src/statistics/OsStatisticsImpl.cpp
@@ -21,7 +21,7 @@
 
 #include "ace/OS.h"
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * An implementation of {@link Statistics} that stores its statistics

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/OsStatisticsImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/PoolStatsSampler.cpp 
b/src/cppcache/src/statistics/PoolStatsSampler.cpp
index 7e729a6..87a8880 100644
--- a/src/cppcache/src/statistics/PoolStatsSampler.cpp
+++ b/src/cppcache/src/statistics/PoolStatsSampler.cpp
@@ -23,7 +23,7 @@
 #include <ClientHealthStats.hpp>
 #include <NanoTimer.hpp>
 #include "HostStatHelper.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 using namespace apache::geode::client;
 const char* PoolStatsSampler::NC_PSS_Thread = "NC PSS Thread";
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/PoolStatsSampler.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/PoolStatsSampler.hpp 
b/src/cppcache/src/statistics/PoolStatsSampler.hpp
index 1c69bab..7c7f10f 100644
--- a/src/cppcache/src/statistics/PoolStatsSampler.hpp
+++ b/src/cppcache/src/statistics/PoolStatsSampler.hpp
@@ -29,7 +29,9 @@ class ThinClientPoolDM;
 }  // namespace geode
 }  // namespace apache
 using namespace apache::geode::client;
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 class StatisticsManager;
 class CPPCACHE_EXPORT PoolStatsSampler : public ACE_Task_Base {
  public:
@@ -54,5 +56,7 @@ class CPPCACHE_EXPORT PoolStatsSampler : public ACE_Task_Base 
{
   ACE_Recursive_Thread_Mutex m_lock;
   static const char* NC_PSS_Thread;
 };
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/ProcessStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/ProcessStats.cpp 
b/src/cppcache/src/statistics/ProcessStats.cpp
index e19c97f..50144c9 100644
--- a/src/cppcache/src/statistics/ProcessStats.cpp
+++ b/src/cppcache/src/statistics/ProcessStats.cpp
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 #include "ProcessStats.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * Creates a new <code>ProcessStats</code> that wraps the given

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/ProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/ProcessStats.hpp 
b/src/cppcache/src/statistics/ProcessStats.hpp
index 24010aa..5e23c6b 100644
--- a/src/cppcache/src/statistics/ProcessStats.hpp
+++ b/src/cppcache/src/statistics/ProcessStats.hpp
@@ -25,7 +25,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Abstracts the process statistics that are common on all platforms.
@@ -72,5 +74,7 @@ class CPPCACHE_EXPORT ProcessStats {
    */
   virtual ~ProcessStats();
 };
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 #endif  // _GEMFIRE_STATISTICS_PROCESSSTATS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/SolarisProcessStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/SolarisProcessStats.cpp 
b/src/cppcache/src/statistics/SolarisProcessStats.cpp
index 2aa1eab..f4f5bb8 100644
--- a/src/cppcache/src/statistics/SolarisProcessStats.cpp
+++ b/src/cppcache/src/statistics/SolarisProcessStats.cpp
@@ -20,7 +20,7 @@
 #include "SolarisProcessStats.hpp"
 #include "GemfireStatisticsFactory.hpp"
 #include "HostStatHelperSolaris.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * <P>This class provides the interface for statistics about a

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/SolarisProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/SolarisProcessStats.hpp 
b/src/cppcache/src/statistics/SolarisProcessStats.hpp
index c8644f4..e9ac059 100644
--- a/src/cppcache/src/statistics/SolarisProcessStats.hpp
+++ b/src/cppcache/src/statistics/SolarisProcessStats.hpp
@@ -28,7 +28,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * <P>This class provides the interface for statistics about a
  * Solaris operating system process that is using a GemFire system.
@@ -75,6 +77,8 @@ class CPPCACHE_EXPORT SolarisProcessStats : public 
ProcessStats {
 
 };  // Class SolarisProcessStats
 
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //_GEMFIRE_STATISTICS_SOLARISPROCESSSTATS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatArchiveWriter.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatArchiveWriter.cpp 
b/src/cppcache/src/statistics/StatArchiveWriter.cpp
index 066059e..1932287 100644
--- a/src/cppcache/src/statistics/StatArchiveWriter.cpp
+++ b/src/cppcache/src/statistics/StatArchiveWriter.cpp
@@ -29,7 +29,7 @@
 #include <NanoTimer.hpp>
 
 using namespace apache::geode::client;
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 // Constructor and Member functions of StatDataOutput class
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatArchiveWriter.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatSamplerStats.cpp 
b/src/cppcache/src/statistics/StatSamplerStats.cpp
index bb151be..828fb42 100644
--- a/src/cppcache/src/statistics/StatSamplerStats.cpp
+++ b/src/cppcache/src/statistics/StatSamplerStats.cpp
@@ -16,7 +16,7 @@
  */
 
 #include "StatSamplerStats.hpp"
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
   * Statistics related to the statistic sampler.

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatSamplerStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatSamplerStats.hpp 
b/src/cppcache/src/statistics/StatSamplerStats.hpp
index a2650f9..bc5c75e 100644
--- a/src/cppcache/src/statistics/StatSamplerStats.hpp
+++ b/src/cppcache/src/statistics/StatSamplerStats.hpp
@@ -28,7 +28,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 class StatisticsFactory;
 /**
@@ -49,5 +51,7 @@ class CPPCACHE_EXPORT StatSamplerStats {
   void setInitialValues();
   ~StatSamplerStats();
 };
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 #endif  //_GEMFIRE_STATISTICS_STATISTICSSAMPLERSTATISTICS_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp 
b/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
index 948d109..78f0a2a 100644
--- a/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
+++ b/src/cppcache/src/statistics/StatisticDescriptorImpl.cpp
@@ -19,7 +19,7 @@
 
 #include <ace/OS.h>
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 const char* StatisticDescriptorImpl::IntTypeName = "int_t";
 const char* StatisticDescriptorImpl::LongTypeName = "Long";

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticDescriptorImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticDescriptorImpl.hpp 
b/src/cppcache/src/statistics/StatisticDescriptorImpl.hpp
index e63f667..52598c2 100644
--- a/src/cppcache/src/statistics/StatisticDescriptorImpl.hpp
+++ b/src/cppcache/src/statistics/StatisticDescriptorImpl.hpp
@@ -25,7 +25,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 typedef enum { INT_TYPE = 5, LONG_TYPE = 6, DOUBLE_TYPE = 8 } FieldType;
 
@@ -242,6 +244,8 @@ s
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  //  _GEMFIRE_STATISTICS_STATISTICDESCRIPTORIMPL_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/Statistics.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/Statistics.cpp 
b/src/cppcache/src/statistics/Statistics.cpp
index 2b5d2d9..aa37c77 100644
--- a/src/cppcache/src/statistics/Statistics.cpp
+++ b/src/cppcache/src/statistics/Statistics.cpp
@@ -16,7 +16,7 @@
  */
 
 #include <gfcpp/statistics/Statistics.hpp>
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 void Statistics::close() {}
 

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticsFactory.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsFactory.cpp 
b/src/cppcache/src/statistics/StatisticsFactory.cpp
index d09669d..4341c4e 100644
--- a/src/cppcache/src/statistics/StatisticsFactory.cpp
+++ b/src/cppcache/src/statistics/StatisticsFactory.cpp
@@ -17,9 +17,13 @@
 
 #include "GemfireStatisticsFactory.hpp"
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 StatisticsFactory* StatisticsFactory::getExistingInstance() {
   return GemfireStatisticsFactory::getExistingInstance();
 }
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticsManager.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsManager.cpp 
b/src/cppcache/src/statistics/StatisticsManager.cpp
index 743c9df..488b590 100644
--- a/src/cppcache/src/statistics/StatisticsManager.cpp
+++ b/src/cppcache/src/statistics/StatisticsManager.cpp
@@ -33,7 +33,7 @@
 #include "OsStatisticsImpl.hpp"
 
 using namespace apache::geode::client;
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
  * static member initialization
@@ -106,7 +106,7 @@ StatisticsManager::~StatisticsManager() {
           LOGFINEST("Leftover statistic: %s", temp.c_str());
           /* adongre
            * Passing null variable "*iterFind" to function
-           * 
"gemfire_statistics::StatisticsManager::deleteStatistics(gemfire_statistics::Statistics
+           * 
"apache::geode::statistics::StatisticsManager::deleteStatistics(apache::geode::statistics::Statistics
            * *&)",
            * which dereferences it.
            * FIX : Put the call into the if condition

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticsManager.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsManager.hpp 
b/src/cppcache/src/statistics/StatisticsManager.hpp
index fd076ed..dac207e 100644
--- a/src/cppcache/src/statistics/StatisticsManager.hpp
+++ b/src/cppcache/src/statistics/StatisticsManager.hpp
@@ -34,7 +34,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Head Application Manager for Statistics Module.
@@ -123,6 +125,8 @@ class StatisticsManager {
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  //  _GEMFIRE_STATISTICS_STATISTICSAPPMANAGER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticsTypeImpl.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsTypeImpl.cpp 
b/src/cppcache/src/statistics/StatisticsTypeImpl.cpp
index adb0c68..e1bea61 100644
--- a/src/cppcache/src/statistics/StatisticsTypeImpl.cpp
+++ b/src/cppcache/src/statistics/StatisticsTypeImpl.cpp
@@ -19,7 +19,7 @@
 #include "StatisticDescriptorImpl.hpp"
 #include <string>
 #include <ace/OS.h>
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 /**
 * Gathers together a number of {@link StatisticDescriptor statistics}

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatisticsTypeImpl.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatisticsTypeImpl.hpp 
b/src/cppcache/src/statistics/StatisticsTypeImpl.hpp
index 0070569..ac35eb6 100644
--- a/src/cppcache/src/statistics/StatisticsTypeImpl.hpp
+++ b/src/cppcache/src/statistics/StatisticsTypeImpl.hpp
@@ -27,7 +27,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * Gathers together a number of {@link StatisticDescriptor statistics}
@@ -93,6 +95,8 @@ class StatisticsTypeImpl : public StatisticsType {
   //                                      StatisticsTypeFactory factory);
 
 };  // class
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 
 #endif  // ifndef _GEMFIRE_STATISTICS_STATISTICSTYPEIMPL_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatsDef.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/StatsDef.hpp 
b/src/cppcache/src/statistics/StatsDef.hpp
index 3ef2243..e0835f3 100644
--- a/src/cppcache/src/statistics/StatsDef.hpp
+++ b/src/cppcache/src/statistics/StatsDef.hpp
@@ -21,7 +21,9 @@
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 #define MAX_1BYTE_COMPACT_VALUE 127
 #define MIN_1BYTE_COMPACT_VALUE -128 + 7
@@ -46,5 +48,7 @@ typedef enum {
   GFS_OSTYPE_MACOSX = 3
 
 } GFS_OSTYPES;
-}  // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
 #endif  // _GEMFIRE_STATISTICS_STATSDEF_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/WindowsProcessStats.cpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/WindowsProcessStats.cpp 
b/src/cppcache/src/statistics/WindowsProcessStats.cpp
index 3ce3f3f..f97edbf 100644
--- a/src/cppcache/src/statistics/WindowsProcessStats.cpp
+++ b/src/cppcache/src/statistics/WindowsProcessStats.cpp
@@ -22,7 +22,7 @@
 #include "GemfireStatisticsFactory.hpp"
 #include "HostStatHelper.hpp"
 
-using namespace gemfire_statistics;
+using namespace apache::geode::statistics;
 
 WindowsProcessStats::WindowsProcessStats(int64 pid, const char* name) {
   GemfireStatisticsFactory* statFactory =

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/WindowsProcessStats.hpp
----------------------------------------------------------------------
diff --git a/src/cppcache/src/statistics/WindowsProcessStats.hpp 
b/src/cppcache/src/statistics/WindowsProcessStats.hpp
index bd6536e..4d163fc 100644
--- a/src/cppcache/src/statistics/WindowsProcessStats.hpp
+++ b/src/cppcache/src/statistics/WindowsProcessStats.hpp
@@ -29,7 +29,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * <P>This class provides the interface for statistics about a
  * Windows operating system process that is using a GemFire system.
@@ -78,6 +80,8 @@ class CPPCACHE_EXPORT WindowsProcessStats : public 
ProcessStats {
 
   friend class HostStatHelperWin;
 };
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //_GEMFIRE_STATISTICS_WINDOWSPROCESSSTATS_HPP_

Reply via email to
diff --git a/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp 
b/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
index 5f7313a..6a7bace 100644
--- a/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
+++ b/src/cppcache/src/statistics/AtomicStatisticsImpl.hpp
@@ -33,7 +33,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * An implementation of {@link Statistics} that stores its statistics
@@ -43,12 +45,14 @@ namespace gemfire_statistics {
 
 /* adongre
  * CID 28732: Other violation (MISSING_COPY)
  * Class "gemfire_statistics::AtomicStatisticsImpl" owns resources that are
  * managed
  * in its constructor and destructor but has no user-written copy constructor.
  *
  * CID 28718: Other violation (MISSING_ASSIGN)
  * Class "gemfire_statistics::AtomicStatisticsImpl" owns resources that are
  * managed in its constructor and destructor but has no user-written assignment
  * operator.
  *
@@ -238,6 +242,8 @@ class AtomicStatisticsImpl : public Statistics, private 
NonCopyable {
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  //  _GEMFIRE_STATISTICS_ATOMICSTATISTICSIMPL_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/GemfireStatisticsFactory.cpp
----------------------------------------------------------------------
@@ -43,12 +45,14 @@ namespace gemfire_statistics {
 /* adongre
  * CID 28732: Other violation (MISSING_COPY)
- * Class "gemfire_statistics::AtomicStatisticsImpl" owns resources that are
+ * Class "apache::geode::statistics::AtomicStatisticsImpl" owns resources that
+ * are
  * managed
  * in its constructor and destructor but has no user-written copy constructor.
@@ -43,12 +45,14 @@ namespace gemfire_statistics {
  *
  * CID 28718: Other violation (MISSING_ASSIGN)
- * Class "gemfire_statistics::AtomicStatisticsImpl" owns resources that are
+ * Class "apache::geode::statistics::AtomicStatisticsImpl" owns resources that
+ * are
  * managed in its constructor and destructor but has no user-written assignment
  * operator.
diff --git a/src/cppcache/src/statistics/HostStatSampler.hpp 
b/src/cppcache/src/statistics/HostStatSampler.hpp
index acb5c1e..75c5b1e 100644
--- a/src/cppcache/src/statistics/HostStatSampler.hpp
+++ b/src/cppcache/src/statistics/HostStatSampler.hpp
@@ -44,7 +44,9 @@ using namespace apache::geode::client;
 #ifndef GEMFIRE_MAX_STAT_DISK_LIMIT
 #define GEMFIRE_MAX_STAT_DISK_LIMIT (1024LL * 1024LL * 1024LL * 1024LL)
 #endif
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 class StatArchiveWriter;
 class StatisticsManager;
@@ -55,12 +57,12 @@ class StatisticsManager;
 
 /* adongre
  * CID 28733: Other violation (MISSING_COPY)
  * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are
  * managed in its constructor and destructor but has no user-written copy
  * constructor.
  *
  * CID 28719: Other violation (MISSING_ASSIGN) Class
- * "gemfire_statistics::HostStatSampler"
+ * "apache::geode::statistics::HostStatSampler"
  * owns resources that are managed in its constructor and destructor but has no
  * user-written assignment operator.
  *
@@ -245,5 +247,8 @@ class CPPCACHE_EXPORT HostStatSampler : public 
ACE_Task_Base,
 
   static const char* NC_HSS_Thread;
 };
-};      // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
+
 #endif  // _GEMFIRE_STATISTICS_HOSTSTATSAMPLER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/LinuxProcessStats.cpp
----------------------------------------------------------------------
@@ -55,12 +57,12 @@ class StatisticsManager;
 /* adongre
  * CID 28733: Other violation (MISSING_COPY)
- * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are
+ * Class "apache::geode::statistics::OsStatisticsImpl" owns resources that are
  * managed in its constructor and destructor but has no user-written copy
  * constructor.
diff --git a/src/cppcache/src/statistics/OsStatisticsImpl.hpp 
b/src/cppcache/src/statistics/OsStatisticsImpl.hpp
index ba1605a..ccec6ee 100644
--- a/src/cppcache/src/statistics/OsStatisticsImpl.hpp
+++ b/src/cppcache/src/statistics/OsStatisticsImpl.hpp
@@ -27,7 +27,9 @@ using namespace apache::geode::client;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 
 /**
  * An implementation of {@link Statistics} that stores its statistics
@@ -37,12 +39,13 @@ namespace gemfire_statistics {
 
 /* adongre
  * CID 28734: Other violation (MISSING_COPY)
  * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are
  * managed in its constructor and destructor but has no user-written copy
  * constructor.
  *
  * CID 28720: Other violation (MISSING_ASSIGN)
  * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
  *
@@ -250,6 +253,8 @@ class OsStatisticsImpl : public Statistics,
 
 };  // class
 
-}  // namespace gemfire_statistics
+}  // namespace client
+}  // namespace geode
+}  // namespace apache
 
 #endif  // _GEMFIRE_STATISTICS_OSSTATISTICSIMPL_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/PoolStatsSampler.cpp
----------------------------------------------------------------------
@@ -37,12 +39,13 @@ namespace gemfire_statistics {
 /* adongre
  * CID 28734: Other violation (MISSING_COPY)
- * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are
+ * Class "apache::geode::statistics::OsStatisticsImpl" owns resources that are
  * managed in its constructor and destructor but has no user-written copy
  * constructor.
@@ -37,12 +39,13 @@ namespace gemfire_statistics {
  *
  * CID 28720: Other violation (MISSING_ASSIGN)
- * Class "gemfire_statistics::OsStatisticsImpl" owns resources that are managed
+ * Class "apache::geode::statistics::OsStatisticsImpl" owns resources that are
+ * managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
diff --git a/src/cppcache/src/statistics/StatArchiveWriter.hpp 
b/src/cppcache/src/statistics/StatArchiveWriter.hpp
index 1efd760..341bef7 100644
--- a/src/cppcache/src/statistics/StatArchiveWriter.hpp
+++ b/src/cppcache/src/statistics/StatArchiveWriter.hpp
@@ -57,7 +57,9 @@ const int64 NANOS_PER_MILLI = 1000000;
 /** @file
 */
 
-namespace gemfire_statistics {
+namespace apache {
+namespace geode {
+namespace statistics {
 /**
  * Some of the classes which are used by the StatArchiveWriter Class
  * 1. StatDataOutput // Just a wrapper around DataOutput so that the number of
@@ -148,11 +150,12 @@ class CPPCACHE_EXPORT ResourceType : private NonCopyable,
 
 /* adongre
  * CID 28735: Other violation (MISSING_COPY)
  * Class "gemfire_statistics::ResourceInst" owns resources
  * that are managed in its constructor and destructor but has no user-written
  * copy constructor.
  * CID 28721: Other violation (MISSING_ASSIGN)
  * Class "gemfire_statistics::ResourceInst" owns resources that are managed
  * in its constructor and destructor but has no user-written assignment
  * operator.
  *
@@ -259,5 +262,8 @@ class CPPCACHE_EXPORT StatArchiveWriter {
    */
   void flush();
 };
-};      // namespace gemfire_statistics
+}  // namespace statistics
+}  // namespace geode
+}  // namespace apache
+
 #endif  // _GEMFIRE_STATISTICS_STATARCHIVERITER_HPP_

http://git-wip-us.apache.org/repos/asf/geode/blob/984d11c7/src/cppcache/src/statistics/StatSamplerStats.cpp
----------------------------------------------------------------------
@@ -148,11 +150,12 @@ class CPPCACHE_EXPORT ResourceType : private NonCopyable,
 /* adongre
  * CID 28735: Other violation (MISSING_COPY)
- * Class "gemfire_statistics::ResourceInst" owns resources
+ * Class "apache::geode::statistics::ResourceInst" owns resources
  * that are managed in its constructor and destructor but has no user-written
  * copy constructor.
@@ -148,11 +150,12 @@ class CPPCACHE_EXPORT ResourceType : private NonCopyable,
  * copy constructor.
  * CID 28721: Other violation (MISSING_ASSIGN)
- * Class "gemfire_statistics::ResourceInst" owns resources that are managed
+ * Class "apache::geode::statistics::ResourceInst" owns resources that are
+ * managed
  * in its constructor and destructor but has no user-written assignment
  * operator.